import { Element, Component, Prop, h, Host } from '@stencil/core';
/**
 * @slot (default) - content placed within the button
 */
export class AmplifyButton {
    constructor() {
        /** Type of the button: 'button', 'submit' or 'reset' */
        this.type = 'button';
        /** Variant of a button: 'button' | 'anchor | 'icon' */
        this.variant = 'button';
        /** Disabled state of the button */
        this.disabled = false;
    }
    render() {
        return (h(Host, null,
            h("button", { class: {
                    [this.variant]: true,
                }, type: this.type, disabled: this.disabled, onClick: this.handleButtonClick },
                this.variant === 'icon' && (h("amplify-icon", { name: this.icon })),
                h("slot", null))));
    }
    static get is() { return "amplify-button"; }
    static get originalStyleUrls() { return {
        "$": ["amplify-button.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["amplify-button.css"]
    }; }
    static get properties() { return {
        "type": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "ButtonTypes",
                "resolved": "\"button\" | \"reset\" | \"submit\"",
                "references": {
                    "ButtonTypes": {
                        "location": "import",
                        "path": "../../common/types/ui-types"
                    }
                }
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "Type of the button: 'button', 'submit' or 'reset'"
            },
            "attribute": "type",
            "reflect": false,
            "defaultValue": "'button'"
        },
        "variant": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "ButtonVariant",
                "resolved": "\"anchor\" | \"button\" | \"icon\"",
                "references": {
                    "ButtonVariant": {
                        "location": "import",
                        "path": "../../common/types/ui-types"
                    }
                }
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "Variant of a button: 'button' | 'anchor | 'icon'"
            },
            "attribute": "variant",
            "reflect": false,
            "defaultValue": "'button'"
        },
        "handleButtonClick": {
            "type": "unknown",
            "mutable": false,
            "complexType": {
                "original": "(evt: Event) => void",
                "resolved": "(evt: Event) => void",
                "references": {
                    "Event": {
                        "location": "global"
                    }
                }
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "(Optional) Callback called when a user clicks on the button"
            }
        },
        "disabled": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "Disabled state of the button"
            },
            "attribute": "disabled",
            "reflect": false,
            "defaultValue": "false"
        },
        "icon": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "IconNameType",
                "resolved": "\"amazon\" | \"auth0\" | \"ban\" | \"enter-vr\" | \"exit-vr\" | \"facebook\" | \"google\" | \"loading\" | \"maximize\" | \"microphone\" | \"minimize\" | \"photoPlaceholder\" | \"send\" | \"sound\" | \"sound-mute\" | \"warning\"",
                "references": {
                    "IconNameType": {
                        "location": "import",
                        "path": "../amplify-icon/icons"
                    }
                }
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "Name of icon to be placed inside the button"
            },
            "attribute": "icon",
            "reflect": false
        }
    }; }
    static get elementRef() { return "el"; }
}
